{% load foundation_formtags %}
{% if field.is_hidden %}
    {{ field }}
{% else %}

    {% if field.label %}
        <label for="{{ field.auto_id }}" class={% if field.errors %}"error"{% endif %}>
            {{ field.label|safe }}
	            {% if field.field.required  %}
	               <span class="required">*</span>
	            {% endif %}
        </label>
        {% if field|is_checkbox %}
           {{ field }}
           {% if field.help_text %}
                <small>{{ field.help_text|safe }}</small>
            {% endif %}
            {% for error in field.errors %}
                <small class="error chk">{{ error }}</small>
            {% endfor %}
        {% else %}
            {{ field }}
            {% for error in field.errors %}
                <small class="error">{{ error }}</small>
            {% endfor %}
            {% if field.help_text %}
                <small>{{ field.help_text|safe }}</small>
            {% endif %}

        {% endif %}
    {% endif %}
{% endif %}
